@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.91
+# FitGallery 0.92
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -26,6 +26,7 @@
 
 include 'common_html.php';
 include 'common_sec.php';
+include 'config/config-common.php';
 
 function html_exif_info($galeria,$valor)
 {
@@ -71,6 +72,6 @@ $valor=check_input($_GET['valor'],VALID_CHARS);
 
 if ($galeria=='' || $valor=='') exit_error('Missing argument.');
 
-html_exif_info($galeria,$valor);
+if ($show_exif_info) html_exif_info($galeria,$valor);
 
 ?> 
