@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.91
+# FitGallery 0.92
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -25,6 +25,7 @@
 #    http://www.gnu.org/licenses/gpl.html
 
 include 'common_sec.php';
+include 'config/config-common.php';
 
 function exif_thumb($valor,$galeria)
 {
@@ -46,6 +47,6 @@ $galeria=check_input($_GET['galeria'],VALID_CHARS);
 
 if ($img=='' || $galeria=='') exit_error('Missing argument.');
 
-exif_thumb($img,$galeria);
+if ($show_exif_thumbs || $show_exif_info) exif_thumb($img,$galeria);
 
 ?> 
