@@ -1,10 +1,10 @@
 <?php
 
-# FitGallery 0.91
+# FitGallery 0.92
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
-# remote scan dir
+# scan dir
 
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -30,9 +30,13 @@ while ($fileimgs = readdir($handledir))
   {
     if ($fileimgs != '.' && $fileimgs != '..')
      {
-       if ($primero == 'x') $primero=$fileimgs;
-       $subtotal += filesize("$dirgal/$file/$dirimgs/$fileimgs");
-       $numimgs += 1;
+       $itemf="$dirgal/$file/$dirimgs/$fileimgs";
+       if (is_readable($itemf))
+       {
+         if ($primero == 'x') $primero=$fileimgs;
+         $subtotal += filesize($itemf);
+         $numimgs += 1;
+       }
      }
   }
 
