@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.91
+# FitGallery 0.92
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -60,43 +60,41 @@ while ($file = readdir($handle))
 { 
  if ($file != '.' && $file != '..')
   {
-    $arr[$n]['date']=date($date_string,filemtime("$ruta/$file"));
-    $arr[$n]['file']=$file;
-    $arr[$n]['bytes']=filesize("$ruta/$file");
-    $arr[$n]['medium']=$h_medium;
-    $arr[$n]['thumb']=$h_thumb;
-    if (es_img("$ruta/$file",$content))
+    $item="$ruta/$file";
+    if (is_readable($item))
     {
-        $arr[$n]['size']=getimagesize("$ruta/$file");
-        $arr[$n]['exif']=false;
-        $arr[$n]['exif_thumb']=false;
-        $image_type=$arr[$n]['size'][2];
-        if ($image_type==IMAGETYPE_JPEG)
-        {
-          if ($show_exif_thumbs)
-            if (exif_thumbnail("$ruta/$file",$exif_w,$exif_h))
-              if ($exif_h<=$h_thumb)
-                $arr[$n]['exif_thumb']=true;
-          
-          if ($show_exif_info)
-            if (exif_read_data("$ruta/$file",ANY_TAG,false,false))
-            {
-               $arr[$n]['exif']=true;
-               $any_exif=true;
-            }
-        }
+      $arr[$n]['date']=date($date_string,filemtime($item));
+      $arr[$n]['file']=$file;
+      $arr[$n]['bytes']=filesize($item);
+      $arr[$n]['medium']=$h_medium;
+      $arr[$n]['thumb']=$h_thumb;
+      if (es_img($item,$content))
+      {
+          $arr[$n]['size']=getimagesize($item);
+          $arr[$n]['exif']=false;
+          $image_type=$arr[$n]['size'][2];
+          if ($image_type==IMAGETYPE_JPEG)
+          {
+            if ($show_exif_info)
+              if (exif_read_data($item,ANY_TAG,false,false))
+              {
+                 $arr[$n]['exif']=true;
+                 $any_exif=true;
+              }
+          }
+      }
+      elseif ($video=es_video($item))
+      {
+          $arr[$n]['size'][0]=$video->getFrameWidth();
+          $arr[$n]['size'][1]=$video->getFrameHeight();
+          $arr[$n]['size'][2]=0;
+          $arr[$n]['dur']=dur_string($video->getDuration());
+          if ($arr[$n]['size'][0]==0 || $arr[$n]['size'][1]==0) { $arr[$n]['medium']=0; $arr[$n]['thumb']=0; }
+      }
+      else { $arr[$n]['medium']=0; $arr[$n]['thumb']=0; }
+      $total += $arr[$n]['bytes'];
+      $n++;
     }
-    elseif ($video=es_video("$ruta/$file"))
-    {
-        $arr[$n]['size'][0]=$video->getFrameWidth();
-        $arr[$n]['size'][1]=$video->getFrameHeight();
-        $arr[$n]['size'][2]=0;
-        $arr[$n]['dur']=dur_string($video->getDuration());
-        if ($arr[$n]['size'][0]==0 || $arr[$n]['size'][1]==0) { $arr[$n]['medium']=0; $arr[$n]['thumb']=0; }
-    }
-    else { $arr[$n]['medium']=0; $arr[$n]['thumb']=0; }
-    $total += $arr[$n]['bytes'];
-    $n++;
   }
 }
 closedir($handle); 
@@ -156,7 +154,7 @@ if ($para2 >= $numero_arch) $para2 = $nummenosuno;
 for ( $i=$para ; $i <= $para2 ; $i++) 
     html_image($ruta,$galeria,$arr[$i]['medium'],$text_medium,$arr[$i]['thumb'],$i,$arr[$i]['file'],
                $arr[$i]['size'],$arr[$i]['bytes'],$arr[$i]['date'],
-               $arr[$i]['exif_thumb'],$arr[$i]['exif'],$text_exif,&$any_exif,$arr[$i]['dur']);
+               $arr[$i]['exif'],$text_exif,&$any_exif,$arr[$i]['dur']);
 
 html_sep();
 
@@ -241,7 +239,7 @@ echo '</p>';
 
 
 function html_image($ruta,$galeria,$h_medium,$text_medium,$h_thumb,$i,$valor,$size,$bytes,$fecha,
-                     $exif_thumb,$exif,$text_exif,$any_exif,$dur)
+                     $exif,$text_exif,$any_exif,$dur)
 {
    echo "
    <div class=\"figure\">
@@ -249,12 +247,8 @@ function html_image($ruta,$galeria,$h_medium,$text_medium,$h_thumb,$i,$valor,$si
    if ($h_thumb)
    {
    echo "
-   <a href=\"$ruta/$valor\">\n";
-   if ($exif_thumb)
-     $thumbsrc="exif_thumb.php?img=$valor&amp;galeria=$galeria";
-   else
-     $thumbsrc="thumb.php?galeria=$galeria&amp;valor=$valor&amp;tipo=t";
-   echo "   <img class=\"thumbnail\" src=\"$thumbsrc\" alt=\"$valor\">
+   <a href=\"$ruta/$valor\">
+   <img class=\"thumbnail\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;tipo=t\" alt=\"$valor\">
    </a>
    <br>\n";
    }
